%global required_pulp_version 2.13

Name:		pulp-ostree
Version:	1.2.1
Release:	3%{?dist}
BuildArch:	noarch

License:	GPLv2+
Summary:	Support for OSTree content in the Pulp platform
URL:		https://github.com/pulp/pulp_ostree
Source0:	https://github.com/pulp/pulp_ostree/archive/%{name}-%{version}-1.tar.gz

BuildRequires:	python2-devel
BuildRequires:	python2-setuptools
BuildRequires:	python2-sphinx


%description
Provides a collection of platform plugins and client extensions support
for OSTree content.


%prep
%autosetup -n pulp_ostree-%{name}-%{version}-1


%build
for directory in $(find . -type f -name "setup.py" | xargs dirname)
do
    pushd $directory
    %py2_build
    popd
done

pushd docs
make %{?_smp_mflags} html
# We don't want to install the objects.inf, because it is a build-time database
rm _build/html/objects.inv
popd


%install
for directory in $(find . -type f -name "setup.py" | xargs dirname)
do
    pushd $directory
    %py2_install
    popd
done

install -d %{buildroot}/%{_sysconfdir}/httpd/conf.d/
install -d %{buildroot}/%{_sysconfdir}/pulp/server/plugins.conf.d/
install -d %{buildroot}/%{_var}/lib/pulp/published/ostree/

install -pm644 plugins/etc/httpd/conf.d/* %{buildroot}/%{_sysconfdir}/httpd/conf.d/
install -pm644 plugins/etc/pulp/server/plugins.conf.d/* \
    %{buildroot}/%{_sysconfdir}/pulp/server/plugins.conf.d/


# --- Admin Extensions
%package admin-extensions
Summary: The OSTree admin client extensions
Requires: python2-pulp-ostree-common = %{version}
Requires: pulp-admin-client >= %{required_pulp_version}


%description admin-extensions
pulp-admin extensions for OSTree support


%files admin-extensions
%license LICENSE
%doc AUTHORS COPYRIGHT
%{python_sitelib}/pulp_ostree/extensions/admin/
%{python_sitelib}/pulp_ostree_extensions_admin*.egg-info


# ---- OSTree Documentation
%package doc
Summary: Pulp documentation


%description doc
Documentation for the Pulp OSTree plugins.


%files doc
%license LICENSE
%doc AUTHORS COPYRIGHT
%doc docs/_build/html/*


# ---- Plugins
%package plugins
Summary: Pulp OSTree plugins
Requires: ostree >= 2015.8
Requires: pygobject3
Requires: python2-gnupg
Requires: python2-pulp-ostree-common = %{version}
Requires: pulp-server >= %{required_pulp_version}


%description plugins
Provides a collection of platformed plugins that extend the Pulp platform
to provide OSTree specific support


%files plugins
%license LICENSE
%doc AUTHORS COPYRIGHT
%config(noreplace) %{_sysconfdir}/httpd/conf.d/pulp_ostree.conf
%config(noreplace) %{_sysconfdir}/pulp/server/plugins.conf.d/ostree_distributor.json
%config(noreplace) %{_sysconfdir}/pulp/server/plugins.conf.d/ostree_importer.json
%{python_sitelib}/pulp_ostree/plugins/
%{python_sitelib}/pulp_ostree_plugins*.egg-info
%attr(-, apache, apache) %dir %{_var}/lib/pulp/published/ostree


# ---- OSTree Common
%package -n python2-pulp-ostree-common
Summary: Pulp OSTree support common library
Requires: python2-pulp-common >= %{required_pulp_version}
%{?python_provide:%python_provide python2-pulp-ostree-common}


%description -n python2-pulp-ostree-common
Common libraries for python2-pulp-ostree


%files -n python2-pulp-ostree-common
%license LICENSE
%doc AUTHORS COPYRIGHT
%dir %{python_sitelib}/pulp_ostree
%{python_sitelib}/pulp_ostree/__init__.py*
%{python_sitelib}/pulp_ostree/common/
%dir %{python_sitelib}/pulp_ostree/extensions
%{python_sitelib}/pulp_ostree/extensions/__init__.py*
%{python_sitelib}/pulp_ostree_common*.egg-info


%changelog
* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Jun 21 2017 Patrick Creech <pcreech@redhat.com> - 1.2.1-2
- Update required pulp version

* Tue Apr 25 2017 Bihan Zhang <bizhang@redhat.com> - 1.2.1-1
- Update to 1.2.1

* Mon Feb 27 2017 Bihan Zhang <bizhang@redhat.com> - 1.2.0-1
- Update to 1.2.0

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Sep 21 2016 Patrick Creech <pcreech@redhat.com> - 1.1.3-3
- Remove trailing .0 on pulp-version

* Wed Sep 21 2016 Patrick Creech <pcreech@redhat.com> - 1.1.3-2
- Fix pulp-version

* Wed Sep 21 2016 Patrick Creech <pcreech@redhat.com> - 1.1.3-1
- Update to 1.1.3

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.2-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Jul 14 2016 Jeremy Cline <jcline@redhat.com> - 1.1.2-1
- Update to 1.1.2

* Mon May 16 2016 Randy Barlow <rbarlow@redhat.com> - 1.1.1-1
- Update to 1.1.1 (#1337315).
- Change license to GPLv2+ as per the COPYRIGHT file.
- Remove unneeded python2-setuptools dependency.

* Tue May 03 2016 Randy Barlow <rbarlow@redhat.com> - 1.1.0-2
- Depend on python2-gnupg instead of python-gnupg (#1332215).

* Thu Mar 17 2016 Randy Barlow <rbarlow@redhat.com> - 1.1.0-1
- Update to 1.1.0.

* Wed Mar 09 2016 Randy Barlow <rbarlow@redhat.com> - 1.1.0-0.9.rc.2
- Add some missing dependencies.

* Wed Mar 09 2016 Randy Barlow <rbarlow@redhat.com> - 1.1.0-0.9.rc.1
- Update to the 1.1.0 release candidate.

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-0.4.beta.1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 29 2016 Patrick Creech <pcreech@redhat.com> 1.1.0-0.4.beta.1
- Bumping to beta 0.4.beta

* Mon Jan 25 2016 Patrick Creech <pcreech@redhat.com> 1.1.0-0.3.beta.1
- Initial Release
